@@ -3,8 +3,9 @@ Main interface for kafka service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.kafka import (
+    from mypy_boto3_kafka import (
         Client,
         KafkaClient,
         ListClusterOperationsPaginator,
@@ -13,7 +14,7 @@ Usage::
         ListConfigurationsPaginator,
         ListKafkaVersionsPaginator,
         ListNodesPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -26,6 +27,7 @@ Usage::
     list_configurations_paginator: ListConfigurationsPaginator = client.get_paginator("list_configurations")
     list_kafka_versions_paginator: ListKafkaVersionsPaginator = client.get_paginator("list_kafka_versions")
     list_nodes_paginator: ListNodesPaginator = client.get_paginator("list_nodes")
+    ```
 """
 from mypy_boto3_kafka.client import KafkaClient as Client, KafkaClient
 from mypy_boto3_kafka.paginator import (
