@@ -3,17 +3,19 @@ Main interface for kafka service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.kafka import KafkaClient
+    from mypy_boto3_kafka import KafkaClient
 
     session = boto3.Session()
 
     client: KafkaClient = boto3.client("kafka")
     session_client: KafkaClient = session.client("kafka")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, IO, List, TYPE_CHECKING, Type, Union, overload
+from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_kafka.paginator import (
     ListClusterOperationsPaginator,
@@ -108,7 +110,7 @@ class KafkaClient:
     def create_configuration(
         self,
         Name: str,
-        ServerProperties: Union[bytes, IO],
+        ServerProperties: bytes,
         Description: str = None,
         KafkaVersions: List[str] = None,
     ) -> CreateConfigurationResponseTypeDef:
