@@ -3,8 +3,11 @@ Main interface for kafka service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.kafka import (
+
+    from mypy_boto3_kafka import KafkaClient
+    from mypy_boto3_kafka import (
         ListClusterOperationsPaginator,
         ListClustersPaginator,
         ListConfigurationRevisionsPaginator,
@@ -21,6 +24,7 @@ Usage::
     list_configurations_paginator: ListConfigurationsPaginator = client.get_paginator("list_configurations")
     list_kafka_versions_paginator: ListKafkaVersionsPaginator = client.get_paginator("list_kafka_versions")
     list_nodes_paginator: ListNodesPaginator = client.get_paginator("list_nodes")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Iterator, TYPE_CHECKING
