@@ -3,13 +3,15 @@ Main interface for kafka service type definitions.
 
 Usage::
 
-    from mypy_boto3.kafka.type_defs import BrokerEBSVolumeInfoTypeDef
+    ```python
+    from mypy_boto3_kafka.type_defs import BrokerEBSVolumeInfoTypeDef
 
     data: BrokerEBSVolumeInfoTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
-from typing import Dict, IO, List, Union
+from typing import Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -406,7 +408,7 @@ DescribeConfigurationRevisionResponseTypeDef = TypedDict(
         "CreationTime": datetime,
         "Description": str,
         "Revision": int,
-        "ServerProperties": Union[bytes, IO],
+        "ServerProperties": bytes,
     },
     total=False,
 )
